@@ -8,3 +8,7 @@ class QueuedObject(object):
         raise NotImplementedError()
     def __repr__(self):
         return "<%s>" % self.describe()
+    def whenever(self):
+        self.target.__forge__.forge.queue.allow_whenever(self)
+        return self
+
